/*
 * "Hello World" example.
 *
 * This example prints 'Hello from Nios II' to the STDOUT stream. It runs on
 * the Nios II 'standard', 'full_featured', 'fast', and 'low_cost' example
 * designs. It runs with or without the MicroC/OS-II RTOS and requires a STDOUT
 * device in your system's hardware.
 * The memory footprint of this hosted application is ~69 kbytes by default
 * using the standard reference design.
 *
 * For a reduced footprint version of this template, and an explanation of how
 * to reduce the memory footprint for a given application, see the
 * "small_hello_world" template.
 *
 */
#include <stdio.h>
#include <sys/alt_timestamp.h>
#include <sys/alt_alarm.h>
#include <sys/alt_irq.h>
#include "alt_types.h"
#include "altera_up_avalon_parallel_port.h"
#include "altera_up_avalon_character_lcd.h"


static alt_alarm alarm;
volatile int edge_capture;
int counter= 0;
alt_up_parallel_port_dev *keys;
alt_up_character_lcd_dev *lcd;



alt_u32 alarm_callback(void* context)
{
	printf("%d\n", counter);
	alt_up_character_lcd_set_cursor_pos(lcd, 0, 0);
	char buffer[14];
	sprintf(buffer, "%2d", counter);
	alt_up_character_lcd_string(lcd, buffer);
	return alt_ticks_per_second()<<2;
}


void noop_function(){
	int i = 0;
	int x = 0;
	for (i = 0; i<100; i++) {
		x = x + 1 + i * 1000;
	}
}

void check_timestamp(){
	alt_u32 time_start;
	alt_u32 time_stop;
	if (alt_timestamp_start() < 0) {
		printf("Lack of timer in the system!");
	}
	time_start = alt_timestamp();

	noop_function();

	time_stop = alt_timestamp();

	printf ("czas wykonywania funkcji: %u cykli\n", (unsigned int) (time_stop - time_start));

	printf ("Czstotliwo timera = %u\n",(unsigned int)alt_timestamp_freq());
}

void przerwanie(void* context, alt_u32 id){
	counter++;
	alt_up_parallel_port_clear_edge_capture(keys);
}

int main()
{
  alt_up_parallel_port_dev *ledr;
  ledr = alt_up_parallel_port_open_dev(LEDR_NAME);

  printf("Hello from Nios II!\n");
  check_timestamp();

  lcd = alt_up_character_lcd_open_dev(LCD_NAME);
  keys = alt_up_parallel_port_open_dev(KEYS_NAME);

	alt_up_character_lcd_init(lcd);

  alt_irq_register(KEYS_IRQ, (void* ) &edge_capture, przerwanie);
  alt_irq_enable(KEYS_IRQ);
  alt_up_parallel_port_set_interrupt_mask(keys, 7);


  // /*
  if (alt_alarm_start(&alarm, alt_ticks_per_second(), alarm_callback, NULL) < 0)
  {
	  printf("Brak zegara.\n");
  }

  for(;;){
	  printf("%u\n", counter );
	  usleep(100000);
	  alt_up_parallel_port_write_data(ledr, counter);
  }

//  */

  return 0;
}
